@@ -26,11 +26,14 @@ class server:
             print("[80%] Server connected!")
         client.sendall(bytes("smtp|"+region+"|"+email+"|"+message,'UTF-8'))
         if debug == "on":
-            print("[100%] Data send to server")
+            print("[98%] Data send to server")
         code = client.recv(4096)
+        code = code.decode('utf-8')
+        client.shutdown(socket.SHUT_RDWR)
+        client.close()
         return code
     def regions():
-        return "SMTP regions: de, uk, us, it, es, tw, cn, ar, au"
+        return "SMTP regions: de, uk, us, it, es, tw, cn, ar, au, fr, ca, in, hk, th, sg, vn, ua, ru, tr, zn"
     def debug(type:str):
         global debug
         if type == "on":
